import { type JSONSchema, type ToJSONSchemaOptions } from '@agentuity/schema';
/**
 * Converts a schema to JSON Schema format.
 * Supports Agentuity schemas (StandardSchemaV1) and Zod schemas.
 * Returns empty object for unknown schema types.
 *
 * @param schema - The schema to convert
 * @param options - Conversion options (only applies to Agentuity schemas)
 */
export declare const toJSONSchema: (schema: any, options?: ToJSONSchemaOptions) => JSONSchema;
//# sourceMappingURL=schema.d.ts.map